@@ -9,7 +9,6 @@
 
 #include "dolphinnavigatorswidgetaction.h"
 #include "dolphintabpage.h"
-#include "views/draganddrophelper.h"
 
 #include <QTabWidget>
 #include <QUrl>
@@ -277,8 +276,6 @@ private:
      */
     const std::optional<const ViewIndex> viewShowingItem(const QUrl &item) const;
 
-    DragAndDropHelper m_dragAndDropHelper;
-
 private:
     QPointer<DolphinTabPage> m_lastViewedTab;
     QPointer<DolphinNavigatorsWidgetAction> m_navigatorsWidget;
