@@ -22,7 +22,8 @@ class KItemListView;
 class QPropertyAnimation;
 
 /**
- * @brief Provides information for creating an instance of KItemListWidget.
+ * @brief Provides generic information for all KItemListWidgets
+ * for which the construction of any specific KItemListWidget isn't required.
  *
  * KItemListView only creates KItemListWidget instances for the visible
  * area. For calculating the required size of all items the expected
@@ -187,6 +188,12 @@ public:
      */
     virtual QPixmap createDragPixmap(const QStyleOptionGraphicsItem *option, QWidget *widget = nullptr);
 
+    /**
+     * Starts an animation that makes clear that the item will be activated soon.
+     * @param timeUntilActivation time in milliseconds until the item will activate
+     */
+    virtual void startActivateSoonAnimation(int timeUntilActivation);
+
 Q_SIGNALS:
     void roleEditingCanceled(int index, const QByteArray &role, const QVariant &value);
     void roleEditingFinished(int index, const QByteArray &role, const QVariant &value);
